# comment_mail_qmail.rb $Revision: 1.10 $
#
# qmailȤäƥĥåߤ᡼Τ餻
#   ư롣
#
# Options:
#   ̤Ǥ(ĥåߥ᡼ϥץ饰):
#     @options['comment_mail.enable']
#          ᡼뤫ɤꤹ롣true()false(ʤ)
#          ̵false
#     @options['comment_mail.header']
#          ᡼Subject˻Ȥʸ󡣿ʬʤ褦˻ꤹ롣
#          ºݤSubjectϡֻʸ:-1פΤ褦ˡդȥֹ椬
#          դʸˡ%³ѻä硢
#          եեޥåȻ򸫤ʤĤޤաפʬ
#          ưŪղäʤʤ(ֹղä)
#          ̵ˤ϶ʸ
#     @options['comment_mail.receivers']
#          ᡼륢ɥ쥹ʸ󡣥ޤǶڤäʣǤ롣
#          ̵ˤɮԤΥɥ쥹ˤʤ롣
#  
#   tdiary.confǤΤ߻Ǥ:
#     @options['comment_mail.qmail']
#          qmail_injectޥɤΥѥꤹ롣
#          ̵ˤϡ'/var/qmail/bin/qmail-inject'ס
#
# Copyright (c) 2003 TADA Tadashi <sho@spc.gr.jp>
# You can distribute this file under the GPL.
#
def comment_mail( text, to )
	begin
		qmail = @conf['comment_mail.qmail'] || '/var/qmail/bin/qmail-inject'
		open( %Q[|'#{qmail.gsub(/'/, '')}' -f '#{@conf.author_mail.gsub( /'/, '' ).untaint}' '#{to.map{|x|x.gsub(/'/,'')}.join("' '")}'], 'w' ) do |o|
			o.write( text )
		end
	rescue
		$stderr.puts $!
	end
end

add_update_proc do
	comment_mail_send if @mode =~ /^(comment|trackbackreceive|pingbackreceive)$/
end

add_conf_proc( 'comment_mail', comment_mail_conf_label, 'tsukkomi' ) do
	comment_mail_basic_setting
	comment_mail_basic_html
end

